==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebForOfStateDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebForOfStateDetailDescription } from "./WebForOfStateDetailDescription";
/**
 * @hidden
 */
var WebForOfStateDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebForOfStateDetailDescriptionMetadata, _super);
    function WebForOfStateDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebForOfStateDetailDescriptionMetadata.b = function (a) {
        if (WebForOfStateDetailDescriptionMetadata.a == null) {
            WebForOfStateDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebForOfStateDetailDescriptionMetadata.c(WebForOfStateDetailDescriptionMetadata.a);
        }
        if (a.j(WebForOfStateDetailDescriptionMetadata.a)) {
            return;
        }
        a.y(WebForOfStateDetailDescriptionMetadata.a);
    };
    WebForOfStateDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:ForOfStateDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("StartIndex", "Number:double");
        a.item("ChunkSize", "Number:double");
    };
    WebForOfStateDetailDescriptionMetadata.d = function (a) {
        WebForOfStateDetailDescriptionMetadata.b(a);
        a.aa("WebForOfStateDetail", function () { return new WebForOfStateDetailDescription(); });
        a.z("WebForOfStateDetail", WebForOfStateDetailDescriptionMetadata.a);
    };
    WebForOfStateDetailDescriptionMetadata.$t = markType(WebForOfStateDetailDescriptionMetadata, 'WebForOfStateDetailDescriptionMetadata');
    WebForOfStateDetailDescriptionMetadata.a = null;
    return WebForOfStateDetailDescriptionMetadata;
}(Base));
export { WebForOfStateDetailDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebForOfStateDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebForOfStateDetailDescription } from "./WebForOfStateDetailDescription";
/**
 * @hidden
 */
var WebForOfStateDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebForOfStateDetailDescriptionMetadata, _super);
    function WebForOfStateDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebForOfStateDetailDescriptionMetadata.b = function (a) {
        if (WebForOfStateDetailDescriptionMetadata.a == null) {
            WebForOfStateDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebForOfStateDetailDescriptionMetadata.c(WebForOfStateDetailDescriptionMetadata.a);
        }
        if (a.k(WebForOfStateDetailDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebForOfStateDetailDescriptionMetadata.a);
    };
    WebForOfStateDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:ForOfStateDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("StartIndex", "Number:double");
        a.item("ChunkSize", "Number:double");
    };
    WebForOfStateDetailDescriptionMetadata.d = function (a) {
        WebForOfStateDetailDescriptionMetadata.b(a);
        a.ac("WebForOfStateDetail", function () { return new WebForOfStateDetailDescription(); });
        a.ab("WebForOfStateDetail", WebForOfStateDetailDescriptionMetadata.a);
    };
    WebForOfStateDetailDescriptionMetadata.$t = markType(WebForOfStateDetailDescriptionMetadata, 'WebForOfStateDetailDescriptionMetadata');
    WebForOfStateDetailDescriptionMetadata.a = null;
    return WebForOfStateDetailDescriptionMetadata;
}(Base));
export { WebForOfStateDetailDescriptionMetadata };
